@@ -6,37 +6,16 @@ package SPVM::Go::Coroutine;
 
 =head1 Name
 
-SPVM::Go::Coroutine - Short Description
+SPVM::Go::Coroutine - Coroutines
 
 =head1 Description
 
-Go::Coroutine class of L<SPVM> has methods for someting.
+The Go::Coroutine class in L<SPVM> has methods to manipulate coroutines.
 
 =head1 Usage
 
   use Go::Coroutine;
 
-=head1 Fields
-
-
-
-=head1 Class Methods
-
-
-
-=head1 Instance Methods
-
-
-
-
-=head1 Repository
-
-
-
-=head1 Author
-
-Yuki Kimoto C<kimoto.yuki@gmail.com>
-
 =head1 Copyright & License
 
 Copyright (c) 2023 Yuki Kimoto
